package mail

import (
	"crypto/tls"
	"fmt"
	globalConfig "git.sheffery.cloud/sheffery/notify/config"
	"gopkg.in/yaml.v3"
	"net/smtp"
	"os"
)

var mail = &config{}

func Mail(toMail string, subject string, content string) error {

	headers := make(map[string]string)
	headers["From"] = "MockingBird <" + mail.From + ">"
	headers["To"] = toMail
	if subject == "" {
		headers["Subject"] = "Notify"
	} else {
		headers["Subject"] = subject
	}

	// Setup message
	message := ""
	for k, v := range headers {
		message += fmt.Sprintf("%s: %s\r\n", k, v)
	}
	message += "\r\n" + content

	config := &tls.Config{
		ServerName: mail.SmtpHost,
	}

	conn, err := tls.Dial("tcp", mail.SmtpHost+":"+mail.SmtpPort, config)
	if err != nil {
		return err
	}

	client, err := smtp.NewClient(conn, mail.SmtpHost)
	if err != nil {
		return err
	}

	// Authentication.
	auth := smtp.PlainAuth("", mail.From, mail.Password, mail.SmtpHost)
	if err = client.Auth(auth); err != nil {
		return err
	}

	if err = client.Mail(mail.From); err != nil {
		return err
	}

	if err = client.Rcpt(toMail); err != nil {
		return err
	}

	writer, err := client.Data()
	if err != nil {
		return err
	}

	_, err = writer.Write([]byte(message))
	if err != nil {
		return err
	}

	if err = writer.Close(); err != nil {
		return err
	}

	if err = client.Quit(); err != nil {
		return err
	}

	return nil
}

type config struct {
	SmtpHost string `yaml:"smtpHost"`
	SmtpPort string `yaml:"smtpPort"`
	From     string `yaml:"from"`
	Password string `yaml:"password"`
}

func init() {
	data, err := os.ReadFile("mail.yml")
	if err != nil {
		data, err = os.ReadFile(globalConfig.Dir() + "mail.yml")
		if err != nil {
			panic("can't find email config file")
		}
	}
	err = yaml.Unmarshal(data, mail)
	if err != nil {
		panic("can't serialize email config file")
	}
	if mail.SmtpHost == "" {
		panic("smtp server host can't be blank")
	}
	if mail.SmtpPort == "" {
		panic("smtp port can't be blank")
	}
	if mail.From == "" {
		panic("smtp from account can't be blank")
	}
	if mail.Password == "" {
		panic("smtp from password can't be blank")
	}
}
