package push

import (
	"net/http"
	"net/url"
	"os"

	globalConfig "git.sheffery.cloud/sheffery/notify/config"

	"gopkg.in/yaml.v3"
)

var push = &config{}

func Simple(content string) error {
	params := url.Values{
		"pushkey": {push.Key},
		"text":    {content},
	}
	_, err := http.PostForm(push.Origin+"/message/push", params)
	return err
}

func Markdown(title string, content string) error {
	params := url.Values{
		"pushkey": {push.Key},
		"text":    {title},
		"desp":    {content},
		"type":    {"markdown"},
	}
	_, err := http.PostForm(push.Origin+"/message/push", params)
	return err
}

func Picture(content string) error {
	params := url.Values{
		"pushkey": {push.Key},
		"text":    {content},
		"type":    {"image"},
	}
	_, err := http.PostForm(push.Origin+"/message/push", params)
	return err
}

type config struct {
	Origin string `yaml:"pushOrigin"`
	Key    string `yaml:"pushKey"`
}

func init() {
	data, err := os.ReadFile("push.yml")
	if err != nil {
		data, err = os.ReadFile(globalConfig.Dir() + "push.yml")
		if err != nil {
			panic("can't find push config file")
		}
	}
	err = yaml.Unmarshal(data, push)
	if err != nil {
		panic("can't serialize push config file")
	}
	if push.Origin == "" {
		panic("push origin can't be blank")
	}
	if push.Key == "" {
		panic("push key can't be blank")
	}
}
